@@ -4,7 +4,7 @@ use strict;
 use Carp;
 use base qw(Unicode::Collate);
 
-our $VERSION = '0.79';
+our $VERSION = '0.81';
 
 use File::Spec;
 
@@ -13,19 +13,22 @@ my $PL_EXT  = '.pl';
 
 my %LocaleFile = map { ($_, $_) } qw(
    af ar as az be bg ca cs cy da eo es et fi fil fo fr gu
-   ha haw hr hu hy ig is ja kk kl ko lt lv mt nb nn nso om
-   pl ro ru se sk sl sq sv tn to tr uk vi wo yo zh
+   ha haw hi hr hu hy ig is ja kk kl kn ko kok ln lt lv
+   mk ml mr mt nb nn nso om or pa pl ro ru se sk sl sq sv
+   tn to tr uk vi wo yo zh
 );
-   $LocaleFile{'default'}         = '';
+   $LocaleFile{'default'} = '';
+# aliases
+   $LocaleFile{'bs'} = 'hr';
+   $LocaleFile{'sr'} = 'ru';
+# short file names
    $LocaleFile{'de__phonebook'}   = 'de_phone';
    $LocaleFile{'es__traditional'} = 'es_trad';
    $LocaleFile{'fi__phonebook'}   = 'fi_phone';
-   $LocaleFile{'mk'} = 'ru';
-   $LocaleFile{'sr'} = 'ru';
-   $LocaleFile{'zh__big5han'}   = 'zh_big5';
-   $LocaleFile{'zh__gb2312han'} = 'zh_gb';
-   $LocaleFile{'zh__pinyin'}    = 'zh_pin';
-   $LocaleFile{'zh__stroke'}    = 'zh_strk';
+   $LocaleFile{'zh__big5han'}     = 'zh_big5';
+   $LocaleFile{'zh__gb2312han'}   = 'zh_gb';
+   $LocaleFile{'zh__pinyin'}      = 'zh_pin';
+   $LocaleFile{'zh__stroke'}      = 'zh_strk';
 
 sub _locale {
     my $locale = shift;
@@ -93,10 +96,11 @@ as		2.0 = 1.8.1
 az		2.0 = 1.8.1
 be		2.0
 bg		2.0
+bs		2.0
 ca		2.0 = 1.8.1 (alt="proposed" type="standard")
 cs		2.0 = 1.8.1 (type="standard")
 cy		2.0 = 1.8.1
-da		2.0 = 1.8.1 (type="standard") [AA's to pass CLDR tests]
+da		2.0 = 1.8.1 (type="standard") [modify aA to pass CLDR tests]
 de__phonebook	2.0 (type="phonebook")
 eo		2.0 = 1.8.1
 es		2.0 (type="standard")
@@ -108,28 +112,36 @@ fil		2.0 (type="standard") = 1.8.1
 fo		2.0 = 1.8.1 (alt="proposed" type="standard")
 fr		2.0 (fr_CA, backwards="on")
 gu		2.0 (type="standard")
-ha
-haw
-hr
-hu
-hy
-ig
-is
-ja
-kk
-kl
-ko
-lt
-lv
-mk
-mt
-nb
-nn
-nso
-om
-pl
-ro
-ru
+ha		2.0
+haw		2.0 = 1.8.1
+hi		2.0
+hr		2.0
+hu		2.0 = 1.8.1 (alt="proposed" type="standard")
+hy		2.0 = 1.8.1
+ig		2.0 = 1.8.1
+is		2.0 = 1.8.1
+ja		2.0 = 1.8.1 (type="standard")
+kk		2.0
+kl		2.0 = 1.8.1
+kn		2.0 (type="standard")
+ko		2.0 = 1.8.1 (type="standard")
+kok		2.0 = 1.8.1
+ln		2.0 (type="standard") = 1.8.1
+lt		2.0
+lv		2.0 (type="standard") = 1.8.1
+mk		2.0
+ml		2.0
+mr		2.0 = 1.8.1
+mt		2.0
+nb		2.0 (type="standard")
+nn		2.0 (type="standard")
+nso		2.0 = 1.8.1
+om		2.0 = 1.8.1
+or		2.0
+pa		2.0 = 1.8.1
+pl		2.0 = 1.8.1
+ro		2.0 (type="standard")
+ru		2.0
 se
 sk
 sl
@@ -260,6 +272,7 @@ this method returns a string C<'default'> meaning no special tailoring.
       az                Azerbaijani (Azeri)
       be                Belarusian
       bg                Bulgarian
+      bs                Bosnian
       ca                Catalan
       cs                Czech
       cy                Welsh
@@ -277,6 +290,7 @@ this method returns a string C<'default'> meaning no special tailoring.
       gu                Gujarati
       ha                Hausa
       haw               Hawaiian
+      hi                Hindi
       hr                Croatian
       hu                Hungarian
       hy                Armenian
@@ -285,15 +299,22 @@ this method returns a string C<'default'> meaning no special tailoring.
       ja                Japanese [1]
       kk                Kazakh
       kl                Kalaallisut
+      kn                Kannada
       ko                Korean [2]
+      kok               Konkani
+      ln                Lingala
       lt                Lithuanian
       lv                Latvian
       mk                Macedonian
+      ml                Malayalam
+      mr                Marathi
       mt                Maltese
       nb                Norwegian Bokmal
       nn                Norwegian Nynorsk
       nso               Northern Sotho
       om                Oromo
+      or                Oriya
+      pa                Punjabi
       pl                Polish
       ro                Romanian
       ru                Russian
@@ -318,13 +339,13 @@ this method returns a string C<'default'> meaning no special tailoring.
     ----------------------------------------------------------
 
 Locales according to the default UCA rules include
+chr (Cherokee),
 de (German),
 en (English),
 ga (Irish),
 id (Indonesian),
 it (Italian),
 ka (Georgian),
-ln (Lingala),
 ms (Malay),
 nl (Dutch),
 pt (Portuguese),
